COLines — so_pysm_models v0.4.dev210

so_pysm_models:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- so_pysm_models v0.4.dev210 »
- COLines

# COLines

class `so_pysm_models.` `COLines`(target_nside, output_units, has_polarization=True, line='10', include_high_galactic_latitude_clouds=False, polarization_fraction=0.001, theta_high_galactic_latitude_deg=20.0, random_seed=1234567, verbose=False, run_mcmole3d=False, pixel_indices=None, mpi_comm=None)

  Bases: `object`

  Class defining attributes for CO line emission. CO templates are extracted from Type 1 CO Planck maps. See further details in https://www.aanda.org/articles/aa/abs/2014/11/aa21553-13/aa21553-13.html

  Parameters: | target_nside : int HEALPix NSIDE of the output maps output_units : str unit string as defined by `pysm.convert_units`, e.g. uK_RJ, K_CMB has_polarization : bool whether or not to simulate also polarization maps line : string CO rotational transitions. Accepted values : 10, 21, 32 polarization_fraction: float polarisation fraction for polarised CO emission. include_high_galactic_latitude_clouds: bool If True it includes a simulation from MCMole3D to include high Galactic Latitude clouds. (See more details at http://giuspugl.github.io/mcmole/index.html) run_mcmole3d: bool If True it simulates HGL cluds by running MCMole3D, otherwise it coadds a map of HGL emission. random_seed: int set random seed for mcmole3d simulations. theta_high_galactic_latitude_deg : float Angle in degree to identify High Galactic Latitude clouds (i.e. clouds whose latitude b is `|b|> theta_high_galactic_latitude_deg`). pixel_indices : ndarray of ints Outputs partial maps given HEALPix pixel indices in RING ordering mpi_comm : mpi4py communicator Read inputs across a MPI communicator, see pysm.read_map

  Methods Summary

  `read_map`(fname[, field]) |
  `signal`() | Simulate CO signal
  `simulate_high_galactic_latitude_CO`() | Coadd High Galactic Latitude CO emission, simulated with MCMole3D.
  `simulate_polarized_emission`(I_map) | Add polarized emission by means of: * an overall constant polarization fraction, * a depolarization map to mimick the line of sigth depolarization effect at low Galactic latitudes * a polarization angle map coming from a dust template (we exploit the observed correlation between polarized dust and molecular emission in star forming regions).

  Methods Documentation

  `read_map`(fname, field=None)
  `signal`()

    Simulate CO signal

  `simulate_high_galactic_latitude_CO`()

    Coadd High Galactic Latitude CO emission, simulated with MCMole3D.

  `simulate_polarized_emission`(I_map)

    Add polarized emission by means of: * an overall constant polarization fraction, * a depolarization map to mimick the line of sigth depolarization effect at low Galactic latitudes * a polarization angle map coming from a dust template (we exploit the observed correlation between polarized dust and molecular emission in star forming regions).